Bottleneck 1.3.1
================

*Release date: 2019-11-18*

Bug Fixes
~~~~~~~~~
- Fix memory leak in :func:`bottleneck.nanmedian` with the default
  argument of ``axis=None``. Thanks to ``@jsmodic`` for reporting!
  (:issue:`276`, :issue:`278`)
- Add regression test for memory leak case (:issue:`279`)

Contributors
~~~~~~~~~~~~

.. contributors:: v1.3.0..v1.3.1
